# -*- coding: utf-8 -*-
# Part of Softhealer Technologies.

from odoo import models, fields, api


class helpdeskSO(models.Model):
    _inherit = 'sale.order'

    sh_sale_ticket_ids = fields.Many2many("helpdesk.ticket", string="Tickets")
    sale_ticket_count = fields.Integer('Ticket',
                                       compute='_compute_sale_ticket_count')

    def action_create_sale_ticket(self):
        context = {}
        if self.partner_id:
            context.update({
                'default_partner_id': self.partner_id.id,
            })
        if self.user_id:
            context.update({
                'default_user_id': self.user_id.id,
            })
        if self:
            context.update({
                'default_sh_sale_order_ids': [(6, 0, self.ids)],
            })
        if self.order_line:
            products = []
            for line in self.order_line:
                if line.product_id.id not in products:
                    products.append(line.product_id.id)
            context.update({'default_product_ids': [(6, 0, products)]})

        return {
            'name': 'Helpdesk Ticket',
            'type': 'ir.actions.act_window',
            'res_model': 'helpdesk.ticket',
            'view_mode': 'form',
            'context': context,
            'target': 'new'
        }

    def _compute_sale_ticket_count(self):
        for record in self:
            record.sale_ticket_count = 0
            tickets = self.env['helpdesk.ticket'].search(
                [('sh_sale_order_ids', 'in', record.ids)], limit=None)
            record.sale_ticket_count = len(tickets.ids)

    def action_view_sale_tickets(self):
        self.ensure_one()
        tickets = self.env['helpdesk.ticket'].sudo().search([
            ('sh_sale_order_ids', 'in', self.ids)
        ])
        action = self.env["ir.actions.actions"]._for_xml_id(
            "sh_all_in_one_helpdesk.helpdesk_ticket_action")
        if len(tickets) > 1:
            action['domain'] = [('id', 'in', tickets.ids)]
        elif len(tickets) == 1:
            form_view = [(self.env.ref(
                'sh_all_in_one_helpdesk.helpdesk_ticket_form_view').id, 'form')
                         ]
            if 'views' in action:
                action['views'] = form_view + \
                    [(state, view)
                     for state, view in action['views'] if view != 'form']
            else:
                action['views'] = form_view
            action['res_id'] = tickets.id
        else:
            action = {'type': 'ir.actions.act_window_close'}
        return action
